@@ -311,6 +311,21 @@ def delete_org_unit(unit=None):
 			AND
 		NOT EXISTS (
 			SELECT 1 FROM clin.encounter where fk_location = %(pk)s
+		)	AND
+		NOT EXISTS (
+			SELECT 1 FROM clin.hospital_stay where fk_org_unit = %(pk)s
+		)	AND
+		NOT EXISTS (
+			SELECT 1 FROM clin.procedure where fk_org_unit = %(pk)s
+		)	AND
+		NOT EXISTS (
+			SELECT 1 FROM clin.test_org where fk_org_unit = %(pk)s
+		)	AND
+		NOT EXISTS (
+			SELECT 1 FROM dem.lnk_org_unit2comm where fk_org_unit = %(pk)s
+		)	AND
+		NOT EXISTS (
+			SELECT 1 FROM dem.lnk_org_unit2ext_id where fk_org_unit = %(pk)s
 		)
 	"""
 	rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}], get_col_idx = False)
@@ -346,8 +361,11 @@ if __name__ == "__main__":
 		sys.exit()
 
 
-	for unit in get_org_units():
-		print unit
+	print cOrgUnit(aPK_obj = 21825)
+
+
+#	for unit in get_org_units():
+#		print unit
 
 	sys.exit(0)
 #============================================================
