@@ -457,7 +457,7 @@ class cIdentity(gmBusinessDBObject.cBusinessDBObject):
 	# identity API
 	#--------------------------------------------------------
 	def _get_gender_symbol(self):
-		return map_gender2symbol[self._payload[self._idx['gender']]]
+		return map_gender2symbol[self._payload[self._idx[u'gender']]]
 
 	gender_symbol = property(_get_gender_symbol, lambda x:x)
 	#--------------------------------------------------------
@@ -1229,6 +1229,8 @@ where id_identity = %(pat)s and id = %(pk)s"""
 		)
 	#----------------------------------------------------------------------
 	def dob_in_range(self, min_distance=u'1 week', max_distance=u'1 week'):
+		if self['dob'] is None:
+			return False
 		cmd = u'select dem.dob_is_in_range(%(dob)s, %(min)s, %(max)s)'
 		rows, idx = gmPG2.run_ro_queries (
 			queries = [{
@@ -1239,6 +1241,8 @@ where id_identity = %(pat)s and id = %(pk)s"""
 		return rows[0][0]
 	#----------------------------------------------------------------------
 	def current_birthday_passed(self):
+		if self['dob'] is None:
+			return None
 		now = gmDateTime.pydt_now_here()
 		if now.month < self['dob'].month:
 			return False
@@ -1252,6 +1256,8 @@ where id_identity = %(pat)s and id = %(pk)s"""
 		return None
 	#----------------------------------------------------------------------
 	def _get_dob_this_year(self):
+		if self['dob'] is None:
+			return None
 		now = gmDateTime.pydt_now_here()
 		return gmDateTime.pydt_replace (
 			dt = self['dob'],
@@ -1698,13 +1704,13 @@ map_gender2mf = {
 #------------------------------------------------------------
 # Maps GNUmed related i18n-aware gender specifiers to a unicode symbol.
 map_gender2symbol = {
-	'm': u'\u2642',
-	'f': u'\u2640',
-	'tf': u'\u26A5\u2640',
+	u'm': u'\u2642',
+	u'f': u'\u2640',
+	u'tf': u'\u26A5\u2640',
 #	'tf': u'\u2642\u2640-\u2640',
-	'tm': u'\u26A5\u2642',
+	u'tm': u'\u26A5\u2642',
 #	'tm': u'\u2642\u2640-\u2642',
-	'h': u'\u26A5',
+	u'h': u'\u26A5',
 #	'h': u'\u2642\u2640',
 	None: u'?\u26A5?'
 }
